@@ -1,7 +1,7 @@
 context("Download")
 
 olddir <- Sys.getenv("YOTOV_DB_DIR")
-Sys.setenv(YOTOV_DB_DIR = normalizePath(file.path(getwd(), "localdb"),
+Sys.setenv(YOTOV_DB_DIR = normalizePath(file.path(getwd(), "yotover"),
   mustWork = FALSE
 ))
 
